pub trait CheckThatResultAssertion<'a, R> {
// Required methods
fn facts_are<B: Borrow<Vec<Fact>>>(&self, facts: B) -> R;
fn facts_are_at_least<B: Borrow<Vec<Fact>>>(&self, facts: B) -> R;
fn fact_value_for_key<I: Into<String>>(
&self,
key: I,
) -> Subject<'_, String, (), R>;
fn fact_keys(&self) -> Subject<'a, HashSet<&String>, (), R>;
}Expand description
Required Methods
Sourcefn facts_are<B: Borrow<Vec<Fact>>>(&self, facts: B) -> R
fn facts_are<B: Borrow<Vec<Fact>>>(&self, facts: B) -> R
Checks that the assertion result contains elements of facts in order.
Sourcefn facts_are_at_least<B: Borrow<Vec<Fact>>>(&self, facts: B) -> R
fn facts_are_at_least<B: Borrow<Vec<Fact>>>(&self, facts: B) -> R
Checks that the assertion result contains elements of facts in order.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.